# Generated by Django 3.1.5 on 2021-04-11 08:11

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='EmailNotificationRecipient',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('email', models.EmailField(max_length=254)),
            ],
            options={
                'verbose_name_plural': 'Email Notification Recipients',
            },
        ),
        migrations.CreateModel(
            name='EmailTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('preview_text', models.CharField(max_length=255)),
                ('preview_text_en', models.CharField(max_length=255, null=True)),
                ('preview_text_el', models.CharField(max_length=255, null=True)),
                ('subject', models.CharField(max_length=255)),
                ('subject_en', models.CharField(max_length=255, null=True)),
                ('subject_el', models.CharField(max_length=255, null=True)),
                ('plain_body', models.TextField()),
                ('plain_body_en', models.TextField(null=True)),
                ('plain_body_el', models.TextField(null=True)),
                ('html_body', models.TextField()),
                ('html_body_en', models.TextField(null=True)),
                ('html_body_el', models.TextField(null=True)),
            ],
        ),
        migrations.CreateModel(
            name='GmailConnectionToken',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('json_string', models.TextField()),
                ('valid', models.BooleanField()),
                ('gmail_address', models.EmailField(max_length=254)),
            ],
        ),
        migrations.CreateModel(
            name='SystemFromEmailAddress',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('email', models.EmailField(max_length=254)),
                ('from_official_name', models.CharField(help_text='This is the text that it gets displayed when viewing the email from the email list on your email client.', max_length=255)),
                ('code_name', models.CharField(max_length=255)),
            ],
            options={
                'verbose_name': 'System From Email Address',
                'verbose_name_plural': 'System From Email Address',
            },
        ),
    ]
