<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>MyCustomMailer</title>

    {% comment %}
    ********************* BE CAREFULL. THIS IS A NO_INDEX TAG. *********************
    {% endcomment %}
    <meta name="robots" content="noindex">
    {% comment %}
    ********************* BE CAREFULL. THIS IS A NO_INDEX TAG. *********************
    {% endcomment %}

    {% load static %}
    {% load i18n %}

    <meta name="viewport" content="width=device-width,initial-scale=1">
    <style type="text/css">
    </style>

    <script type="text/javascript">
        $(document).ready(function () {
        });
    </script>
    {% block head_content %}{% endblock %}

</head>
<body>

{% block content %}{% endblock %}

</body>
</html>
